import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class BackendWalletService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Create backend wallet
     * Create a backend wallet.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    create(requestBody?: {
        label?: string;
    }): CancelablePromise<{
        result: {
            walletAddress: string;
            status: string;
        };
    }>;
    /**
     * Import backend wallet
     * Import an existing wallet as a backend wallet.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    import(requestBody?: ({
        /**
         * AWS KMS Key ID
         */
        awsKmsKeyId: string;
        /**
         * AWS KMS Key ARN
         */
        awsKmsArn: string;
    } | {
        /**
         * GCP KMS Key ID
         */
        gcpKmsKeyId: string;
        /**
         * GCP KMS Key Version ID
         */
        gcpKmsKeyVersionId: string;
    } | ({
        /**
         * The private key of the wallet to import
         */
        privateKey: string;
    } | {
        /**
         * The mnemonic phrase of the wallet to import
         */
        mnemonic: string;
    } | {
        /**
         * The encrypted JSON of the wallet to import
         */
        encryptedJson: string;
        /**
         * The password used to encrypt the encrypted JSON
         */
        password: string;
    }))): CancelablePromise<{
        result: {
            walletAddress: string;
            status: string;
        };
    }>;
    /**
     * Update backend wallet
     * Update a backend wallet.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    update(requestBody: {
        walletAddress: string;
        label?: string;
    }): CancelablePromise<{
        result: {
            walletAddress: string;
            status: string;
        };
    }>;
    /**
     * Get balance
     * Get the native balance for a backend wallet.
     * @param chain Chain ID name
     * @param walletAddress Wallet Address
     * @returns any Default Response
     * @throws ApiError
     */
    getBalance(chain: string, walletAddress: string): CancelablePromise<{
        result: {
            walletAddress: string;
            name: string;
            symbol: string;
            decimals: number;
            value: string;
            displayValue: string;
        };
    }>;
    /**
     * Get all backend wallets
     * Get all backend wallets.
     * @param page The page of wallets to get.
     * @param limit The number of wallets to get per page.
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(page?: number, limit?: number): CancelablePromise<{
        result: Array<{
            /**
             * Wallet Address
             */
            address: string;
            /**
             * Wallet Type
             */
            type: string;
            label: (string | null);
            awsKmsKeyId: (string | null);
            awsKmsArn: (string | null);
            gcpKmsKeyId: (string | null);
            gcpKmsKeyRingId: (string | null);
            gcpKmsLocationId: (string | null);
            gcpKmsKeyVersionId: (string | null);
            gcpKmsResourcePath: (string | null);
        }>;
    }>;
    /**
     * Transfer tokens
     * Transfer native or ERC20 tokens from this wallet to another wallet
     * @param chain Chain ID name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    transfer(chain: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address of the wallet to transfer to
         */
        to: string;
        /**
         * Address of the token to transfer
         */
        currencyAddress: string;
        /**
         * The amount of tokens to transfer
         */
        amount: string;
    }): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Withdraw all funds
     * Withdraw all funds from this wallet to another wallet
     * @param chain Chain ID name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    withdraw(chain: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address to withdraw all funds to
         */
        toAddress: string;
    }): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Send a raw transaction
     * Send a raw transaction with transaction parameters
     * @param chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    sendTransaction(chain: string, xBackendWalletAddress: string, requestBody: {
        toAddress?: string;
        data: string;
        value: string;
    }): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Send a batch of raw transactions
     * Send a batch of raw transactions with transaction parameters
     * @param chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    sendTransactionBatch(chain: string, xBackendWalletAddress: string, requestBody?: Array<{
        toAddress?: string;
        data: string;
        value: string;
    }>): CancelablePromise<{
        result: {
            groupId: string;
            queueIds: Array<string>;
        };
    }>;
    /**
     * Sign a transaction
     * Sign a transaction
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    signTransaction(xBackendWalletAddress: string, requestBody: {
        transaction: {
            to?: string;
            from?: string;
            nonce?: string;
            gasLimit?: string;
            gasPrice?: string;
            data?: string;
            value?: string;
            chainId?: number;
            type?: number;
            accessList?: any;
            maxFeePerGas?: string;
            maxPriorityFeePerGas?: string;
            customData?: Record<string, any>;
            ccipReadEnabled?: boolean;
        };
    }): CancelablePromise<{
        result: string;
    }>;
    /**
     * Sign a message
     * Send a message
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    signMessage(xBackendWalletAddress: string, requestBody: {
        message: string;
    }): CancelablePromise<{
        result: string;
    }>;
    /**
     * Get all transactions
     * Get all transactions for a backend wallet.
     * @param chain Chain ID name
     * @param walletAddress Wallet Address
     * @returns any Default Response
     * @throws ApiError
     */
    getAllTransactions(chain: string, walletAddress: string): CancelablePromise<{
        result: {
            transactions: Array<{
                queueId: (string | null);
                chainId: (string | null);
                fromAddress: (string | null);
                toAddress: (string | null);
                data: (string | null);
                extension: (string | null);
                value: (string | null);
                nonce: (number | null);
                gasLimit: (string | null);
                gasPrice: (string | null);
                maxFeePerGas: (string | null);
                maxPriorityFeePerGas: (string | null);
                transactionType: (number | null);
                transactionHash: (string | null);
                queuedAt: (string | null);
                processedAt: (string | null);
                sentAt: (string | null);
                minedAt: (string | null);
                cancelledAt: (string | null);
                deployedContractAddress: (string | null);
                deployedContractType: (string | null);
                errorMessage: (string | null);
                sentAtBlockNumber: (number | null);
                blockNumber: (number | null);
                status: (string | null);
                /**
                 * Number of times the transaction was retried.
                 */
                retryCount: number;
                retryGasValues: (boolean | null);
                retryMaxFeePerGas: (string | null);
                retryMaxPriorityFeePerGas: (string | null);
                signerAddress: (string | null);
                accountAddress: (string | null);
                target: (string | null);
                sender: (string | null);
                initCode: (string | null);
                callData: (string | null);
                callGasLimit: (string | null);
                verificationGasLimit: (string | null);
                preVerificationGas: (string | null);
                paymasterAndData: (string | null);
                userOpHash: (string | null);
                functionName: (string | null);
                functionArgs: (string | null);
                onChainTxStatus: (number | null);
            }>;
        };
    }>;
}
